// import "core-js/stable";
import "regenerator-runtime/runtime";
import React from "react";
import ReactDOM from "react-dom/client";
import { StytchProvider } from '@stytch/react';
import { StytchUIClient } from '@stytch/vanilla-js';
import App from "./App.jsx";
import ErrorBoundary from "./ErrorBoundary.jsx";
import GlobalStyles from "./styles/GlobalStyles.jsx";
import * as Sentry from "@sentry/react";

Sentry.init({
    dsn: "https://51157e2101be1f443a7e451a3bc842a5@o4508207324266496.ingest.us.sentry.io/4508207626584064",
    integrations: [
        Sentry.browserTracingIntegration({
            instrumentPageLoad: false,
            instrumentNavigation: false,
            enableInp: false,
        }),
    ],
    traceSampleRate: 0.15,
    tracePropagationTargets: ["localhost", /^https:\/\/vondyapi-proxy.com/],
});


import "./index.css";


const stytch = new StytchUIClient(
    'public-token-live-04c8134a-65e3-4abc-8610-8bb9cf3e580a'
);

if (!Object.hasOwn) {
    Object.hasOwn = (obj, prop) => {
        return Object.prototype.hasOwnProperty.call(obj, prop);
    };
}

window.addEventListener('vite:preloadError', (event) => {
    window.location.reload() // for example, refresh the page
})

window.SC_DISABLE_SPEEDY = true;

const preloadedState = window.__PRELOADED_STATE__;


const AppWithProviders = ({ preloadedState }) => (
    <React.StrictMode>
        <ErrorBoundary>
            <GlobalStyles />
            <StytchProvider stytch={stytch}>
                    <App preloadedState={preloadedState} />
            </StytchProvider>
        </ErrorBoundary>
    </React.StrictMode>
);

const rootElement = document.getElementById("root");

async function initializeApp() {
    // Parse token from URL like the edge function does
    let savedWindowData = {};
    try {
        const pathSegments = window.location.pathname.split('/');
        const tokenSegment = pathSegments.find(segment => segment.includes('--'));
        const isServicePage = pathSegments.length === 2 && tokenSegment;
        if (isServicePage && window.initialData && window.initialExamples) {
            console.debug('Initial examples found, skipping')
            savedWindowData.initialExamples = JSON.parse(JSON.stringify(window.initialExamples));
            savedWindowData.initialData = JSON.parse(JSON.stringify(window.initialData));
        }
        if (isServicePage && !window.initialData && !window.initialExamples) {
            console.debug('Fetching initial examples')
            const token = tokenSegment.split('--')[1];

            // Fetch initial data
            const initialData = await fetch(`https://vondyapi-proxy.com/share/ai/${token}?quick=true`).then(res => res.json());
            const examples = await fetch(`https://vondyapi-proxy.com/example-generations/f50764ce-2ba5-47ca-86cc-8bc89cdfada4/?type=ImgGen&check_good=true&limit=15&fetch=first&token=${token}`).then(res => res.json());

            // Set on window before hydration
            if (initialData) {
                window.initialData = initialData;
                savedWindowData.initialData = JSON.parse(JSON.stringify(window.initialData));
            }
            if (examples?.data && Array.isArray(examples.data) && examples.data.length) {
                window.initialExamples = examples.data;
                savedWindowData.initialExamples = JSON.parse(JSON.stringify(window.initialExamples));
            }
        }
        if (!isServicePage) {
            console.debug('Not a service page, skipping')
        }
    }
    catch (e) {
        console.error(`error fetching data during prerender: ${e}`)
    }
    ReactDOM.hydrateRoot(
        rootElement,
        <AppWithProviders preloadedState={preloadedState} />,
        {
            onRecoverableError: () => {
                if (savedWindowData.initialData) {
                    window.initialData = savedWindowData.initialData;
                }
                if (savedWindowData.initialExamples) {
                    window.initialExamples = savedWindowData.initialExamples;
                }
            },
        }
    );
}

if (rootElement.hasChildNodes()) {
    initializeApp();
} else {
    ReactDOM.createRoot(rootElement).render(
        <AppWithProviders />
    );
}



// Clean up the preloaded state
delete window.__PRELOADED_STATE__;
